@@ -36,11 +36,11 @@ class PdbBreakpoint(Op):
     .. code-block:: python
 
         import pytensor
-        import pytensor.tensor as at
+        import pytensor.tensor as pt
         from pytensor.breakpoint import PdbBreakpoint
 
-        input = at.fvector()
-        target = at.fvector()
+        input = pt.fvector()
+        target = pt.fvector()
 
         # Mean squared error between input and target
         mse = (input - target) ** 2
@@ -49,7 +49,7 @@ class PdbBreakpoint(Op):
         # than 100. The breakpoint will monitor the inputs, targets as well
         # as the individual error values
         breakpointOp = PdbBreakpoint("MSE too high")
-        condition = at.gt(mse.sum(), 100)
+        condition = pt.gt(mse.sum(), 100)
         mse, monitored_input, monitored_target = breakpointOp(condition, mse,
                                                               input, target)
 
