@@ -104,7 +104,7 @@ def log10_inplace(a):
 
 
 @scalar_elemwise
-def sgn_inplace(a):
+def sign_inplace(a):
     """sign of `a` (inplace on `a`)"""
 
 
@@ -313,6 +313,11 @@ def iv_inplace(v, x):
     """Modified Bessel function of the first kind of order v (real)."""
 
 
+@scalar_elemwise
+def ive_inplace(v, x):
+    """Exponentially scaled modified Bessel function of the first kind of order v (real)."""
+
+
 @scalar_elemwise
 def sigmoid_inplace(x):
     """Logistic sigmoid function (1 / (1 + exp(-x)), also known as expit or inverse logit"""
