@@ -27,7 +27,7 @@ from typing import Union
 
 import numpy as np
 
-import pytensor.scalar.basic as aes
+import pytensor.scalar.basic as ps
 from pytensor import compile
 from pytensor.compile.ops import ViewOp
 from pytensor.graph import FunctionGraph
@@ -551,7 +551,7 @@ def local_useless_elemwise(fgraph, node):
         # cleaner graph.
         dtype = node.outputs[0].dtype
 
-        if node.op.scalar_op == aes.eq and len(node.inputs) == 2:
+        if node.op.scalar_op == ps.eq and len(node.inputs) == 2:
             if node.inputs[0] == node.inputs[1]:
                 # it is the same var in the graph. That will always be true
                 ret = ones_like(node.inputs[0], dtype=dtype, opt=True)
@@ -559,7 +559,7 @@ def local_useless_elemwise(fgraph, node):
                 # Copy stack trace from input to constant output
                 copy_stack_trace(node.outputs[0], ret)
                 return [ret]
-        elif node.op.scalar_op == aes.neq and len(node.inputs) == 2:
+        elif node.op.scalar_op == ps.neq and len(node.inputs) == 2:
             if node.inputs[0] == node.inputs[1]:
                 # it is the same var in the graph. That will always be false
                 ret = zeros_like(node.inputs[0], dtype=dtype, opt=True)
@@ -568,17 +568,17 @@ def local_useless_elemwise(fgraph, node):
                 copy_stack_trace(node.outputs[0], ret)
                 return [ret]
 
-        elif node.op.scalar_op == aes.mul and len(node.inputs) == 1:
+        elif node.op.scalar_op == ps.mul and len(node.inputs) == 1:
             # No need to copy over any stack trace
             return [node.inputs[0]]
 
-        elif node.op.scalar_op == aes.add and len(node.inputs) == 1:
+        elif node.op.scalar_op == ps.add and len(node.inputs) == 1:
             # No need to copy over any stack trace
             return [node.inputs[0]]
-        elif node.op.scalar_op == aes.identity and len(node.inputs) == 1:
+        elif node.op.scalar_op == ps.identity and len(node.inputs) == 1:
             return [node.inputs[0]]
 
-        elif isinstance(node.op.scalar_op, aes.AND) and len(node.inputs) == 2:
+        elif isinstance(node.op.scalar_op, ps.AND) and len(node.inputs) == 2:
             if isinstance(node.inputs[0], TensorConstant):
                 const_val = extract_constant(
                     node.inputs[0], only_process_constants=True
@@ -603,7 +603,7 @@ def local_useless_elemwise(fgraph, node):
                         # and this rewrite would be wrong
                         return [node.inputs[0].astype(node.outputs[0].dtype)]
 
-        elif isinstance(node.op.scalar_op, aes.OR) and len(node.inputs) == 2:
+        elif isinstance(node.op.scalar_op, ps.OR) and len(node.inputs) == 2:
             if isinstance(node.inputs[0], TensorConstant):
                 const_val = extract_constant(
                     node.inputs[0], only_process_constants=True
@@ -628,7 +628,7 @@ def local_useless_elemwise(fgraph, node):
                         # and this rewrite would be wrong
                         return [ones_like(node.inputs[0], dtype=dtype, opt=True)]
 
-        elif isinstance(node.op.scalar_op, aes.XOR) and len(node.inputs) == 2:
+        elif isinstance(node.op.scalar_op, ps.XOR) and len(node.inputs) == 2:
             if node.inputs[0] is node.inputs[1]:
                 return [zeros_like(node.inputs[0], dtype=dtype, opt=True)]
 
@@ -666,13 +666,13 @@ def local_cast_cast(fgraph, node):
           and the first cast cause an upcast.
 
     """
-    if not isinstance(node.op, Elemwise) or not isinstance(node.op.scalar_op, aes.Cast):
+    if not isinstance(node.op, Elemwise) or not isinstance(node.op.scalar_op, ps.Cast):
         return
     x = node.inputs[0]
     if (
         not x.owner
         or not isinstance(x.owner.op, Elemwise)
-        or not isinstance(x.owner.op.scalar_op, aes.Cast)
+        or not isinstance(x.owner.op.scalar_op, ps.Cast)
     ):
         return
 
@@ -1016,7 +1016,7 @@ def local_useless_switch(fgraph, node):
     if (
         cond_var.owner
         and isinstance(cond_var.owner.op, Elemwise)
-        and isinstance(cond_var.owner.op.scalar_op, aes.LE)
+        and isinstance(cond_var.owner.op.scalar_op, ps.LE)
         and cond_var.owner.inputs[0].owner
         and isinstance(cond_var.owner.inputs[0].owner.op, Shape_i)
         and extract_constant(cond_var.owner.inputs[1], only_process_constants=True) == 0
@@ -1039,14 +1039,14 @@ def local_merge_switch_same_cond(fgraph, node):
     """
     # node must be binary elemwise or add or mul
     if not isinstance(node.op, Elemwise) or not isinstance(
-        node.op.scalar_op, (aes.BinaryScalarOp, aes.Add, aes.Mul)
+        node.op.scalar_op, (ps.BinaryScalarOp, ps.Add, ps.Mul)
     ):
         return
     # all inputs must be switch
     if not all(
         s.owner
         and isinstance(s.owner.op, Elemwise)
-        and isinstance(s.owner.op.scalar_op, aes.Switch)
+        and isinstance(s.owner.op.scalar_op, ps.Switch)
         for s in node.inputs
     ):
         return
